@@ -18,7 +18,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include "../gfal_api.h"
+#include <gfal_api.h>
 
 int main(int argc, char **argv)
 {
